import numpy as np
from pytracking.evaluation.data import Sequence_rgbt, BaseDataset, SequenceList


class VOTrgbtDataset(BaseDataset):
    """
    VOTrgbt dataset

    """
    def __init__(self):
        super().__init__()
        self.base_path = self.env_settings.votrgbt_path
        self.sequence_list = self._get_sequence_list()

    def get_sequence_list(self):
        return SequenceList([self._construct_sequence(s) for s in self.sequence_list])

    def _construct_sequence(self, sequence_name):
        sequence_path = sequence_name
        nz = 5
        ext = 'jpg'
        start_frame = 1

        anno_path = '{}/{}/groundtruth.txt'.format(self.base_path, sequence_name)
        try:
            ground_truth_rect = np.loadtxt(str(anno_path), dtype=np.float64)
        except:
            ground_truth_rect = np.loadtxt(str(anno_path), delimiter=',', dtype=np.float64)

        end_frame = ground_truth_rect.shape[0]

        frames_rgb = ['{base_path}/{sequence_path}/color/{frame:0{nz}}v.{ext}'.format(base_path=self.base_path,
                  sequence_path=sequence_path, frame=frame_num, nz=nz, ext=ext)
                  for frame_num in range(start_frame, end_frame+1)]

        frames_t = ['{base_path}/{sequence_path}/ir/{frame:0{nz}}i.{ext}'.format(base_path=self.base_path,
                  sequence_path=sequence_path, frame=frame_num, nz=nz, ext=ext)
                  for frame_num in range(start_frame, end_frame+1)]

        # Convert gt
        if ground_truth_rect.shape[1] > 4:
            gt_x_all = ground_truth_rect[:, [0, 2, 4, 6]]
            gt_y_all = ground_truth_rect[:, [1, 3, 5, 7]]

            x1 = np.amin(gt_x_all, 1).reshape(-1,1)
            y1 = np.amin(gt_y_all, 1).reshape(-1,1)
            x2 = np.amax(gt_x_all, 1).reshape(-1,1)
            y2 = np.amax(gt_y_all, 1).reshape(-1,1)

            ground_truth_rect = np.concatenate((x1, y1, x2-x1, y2-y1), 1)
        return Sequence_rgbt(sequence_name, frames_rgb, frames_t, 'votrgbt', ground_truth_rect)

    def __len__(self):
        return len(self.sequence_list)

    def _get_sequence_list(self):
        sequence_list= ['afterrain',
                        'aftertree',
                        'baby',
                        'baginhand',
                        'baketballwaliking',
                        'balancebike',
                        'basketball2',
                        'bicyclecity',
                        'bike',
                        'bikeman',
                        'bikemove1',
                        'biketwo',
                        'blueCar',
                        'bluebike',
                        'bus6',
                        'car',
                        'car10',
                        'car20',
                        'car3',
                        'car37',
                        'car4',
                        'car41',
                        'car66',
                        'carLight',
                        'caraftertree',
                        'carnotfar',
                        'carred',
                        'child',
                        'child1',
                        'crossroad',
                        'crouch',
                        'cycle1',
                        'cycle3',
                        'diamond',
                        'dog',
                        'dog11',
                        'elecbike',
                        'elecbikechange2',
                        'face1',
                        'floor-1',
                        'flower2',
                        'fog',
                        'fog6',
                        'green',
                        'greyman',
                        'greywoman',
                        'hotkettle',
                        'man4',
                        'man88',
                        'mandrivecar',
                        'maninblack',
                        'manwithbasketball',
                        'redcar',
                        'supbus',
                        'takeout',
                        'tricycle',
                        'twoelecbike1',
                        'twowoman',
                        'walkingnight',
                        'woman89']

        return sequence_list
